summaryrefslogtreecommitdiff
path: root/epan/dissectors/packet-vnc.c
diff options
context:
space:
mode:
authorBill Meier <wmeier@newsguy.com>2012-07-03 18:49:12 +0000
committerBill Meier <wmeier@newsguy.com>2012-07-03 18:49:12 +0000
commit7882ec57c3ec9bceffd1d8ac611e0b536804e771 (patch)
treea641ef250f3e5bd1dec76914cf156692684daedd /epan/dissectors/packet-vnc.c
parent7a900c81b300906a3037e9793f005ad351aafd15 (diff)
downloadwireshark-7882ec57c3ec9bceffd1d8ac611e0b536804e771.tar.gz
Improve use of the value_string x11_keysym_vals_source[]:
- Compile the value_string only as part of packet-x11.c - Create a value_string_ext to ref the value_string; - packet_vnc.c: Access the value_string using the value_string_ext; - packet-x11.c: Access the value-string using the value_string_ext rather then building a temp GTree from the value_string. svn path=/trunk/; revision=43558
Diffstat (limited to 'epan/dissectors/packet-vnc.c')
-rw-r--r--epan/dissectors/packet-vnc.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/epan/dissectors/packet-vnc.c b/epan/dissectors/packet-vnc.c
index b4f4a25a7e..e5ea125721 100644
--- a/epan/dissectors/packet-vnc.c
+++ b/epan/dissectors/packet-vnc.c
@@ -53,8 +53,8 @@
#include <epan/packet.h>
#include <epan/prefs.h>
#include <epan/expert.h>
#include "packet-x11-keysym.h" /* This contains the X11 value_string
* "keysym_vals_source" that VNC also uses. */
typedef enum {
VNC_SECURITY_TYPE_INVALID = 0,
@@ -2913,7 +2913,7 @@ proto_register_vnc(void)
},
{ &hf_vnc_key,
{ "Key", "vnc.key",
- FT_UINT32, BASE_HEX, VALS(keysym_vals_source), 0x0, /* keysym_vals_source is from packet-x11-keysym.h */
+ FT_UINT32, BASE_HEX | BASE_EXT_STRING, &x11_keysym_vals_source_ext, 0x0, /* keysym_vals_source_exr is from packet-x11.c */
"Key being pressed/depressed", HFILL }
},
@@ -53,8 +53,8 @@
#include <epan/prefs.h>
#include <epan/expert.h>
-#include "packet-x11-keysym.h" /* This contains the X11 value_string
- * "keysym_vals_source" that VNC also uses. */
+#include "packet-x11.h" /* This contains the extern for the X11 value_string_ext
+ * "x11_keysym_vals_source_ext" that VNC uses. */
typedef enum {
VNC_SECURITY_TYPE_INVALID = 0,